export(OFHCohortSynthesizer)
export(add_inpatient_events)
export(generate_ofh_cohort)
export(generate_ofh_population)
export(ofh_build_config)
export(ofh_default_code_config)
export(ofh_default_proportions)
export(ofh_default_record_multipliers)
export(synthesize_drug_exposure)
importFrom(methods,setRefClass)
importFrom(methods,new)
importFrom(stats,runif)
importFrom(utils,read.csv)